@@ -25,8 +25,8 @@
 #include <tqimage.h>
 
 #include <kdebug.h>
-#include <klocale.h>
-#include <kglobal.h>
+#include <tdelocale.h>
+#include <tdeglobal.h>
 
 #include "kis_gray_u16_colorspace.h"
 #include "kis_u16_base_colorspace.h"
