@@ -26,9 +26,9 @@
 
 #include <tqimage.h>
 
-#include <klocale.h>
+#include <tdelocale.h>
 #include <kdebug.h>
-#include <kglobal.h>
+#include <tdeglobal.h>
 
 #include "kis_abstract_colorspace.h"
 #include "kis_u8_base_colorspace.h"
