@@ -27,8 +27,8 @@
 #include <tqcolor.h>
 
 #include <kdebug.h>
-#include <klocale.h>
-#include <kglobal.h>
+#include <tdelocale.h>
+#include <tdeglobal.h>
 
 #include "kis_rgb_u16_colorspace.h"
 #include "kis_u16_base_colorspace.h"
