@@ -28,9 +28,9 @@
 #include <tqpushbutton.h>
 #include <tqslider.h>
 
-#include <kaction.h>
+#include <tdeaction.h>
 #include <kdebug.h>
-#include <klocale.h>
+#include <tdelocale.h>
 #include <kdebug.h>
 #include <knuminput.h>
 
@@ -766,7 +766,7 @@ TQWidget* KisToolMagnetic::createOptionWidget(TQWidget* parent)
     TQGridLayout *box = new TQGridLayout(l, 2, 2, 3);
     box->setColStretch(0, 1);
     box->setColStretch(1, 1);
-    Q_CHECK_PTR(box);
+    TQ_CHECK_PTR(box);
 
     m_mode = new TQLabel(i18n("Automatic mode"), m_optWidget);
     m_lbDistance = new TQLabel(i18n("Distance: "), m_optWidget);
@@ -784,21 +784,21 @@ TQWidget* KisToolMagnetic::createOptionWidget(TQWidget* parent)
     return m_optWidget;
 }
 
-void KisToolMagnetic::setup(KActionCollection *collection)
+void KisToolMagnetic::setup(TDEActionCollection *collection)
 {
-    m_action = static_cast<KRadioAction *>(collection->action(name()));
+    m_action = static_cast<TDERadioAction *>(collection->action(name()));
 
     if (m_action == 0) {
-        KShortcut shortcut(TQt::Key_Plus);
-        shortcut.append(KShortcut(TQt::Key_F9));
-        m_action = new KRadioAction(i18n("Magnetic Outline"),
+        TDEShortcut shortcut(TQt::Key_Plus);
+        shortcut.append(TDEShortcut(TQt::Key_F9));
+        m_action = new TDERadioAction(i18n("Magnetic Outline"),
                                     "tool_moutline",
                                     shortcut,
                                     this,
                                     TQT_SLOT(activate()),
                                     collection,
                                     name());
-        Q_CHECK_PTR(m_action);
+        TQ_CHECK_PTR(m_action);
 
         m_action->setToolTip(i18n("Magnetic Selection: move around an edge to select it. Hit Ctrl to enter/quit manual mode, and double click to finish."));
         m_action->setExclusiveGroup("tools");
