@@ -21,14 +21,14 @@
 #ifndef COLORRANGE_H
 #define COLORRANGE_H
 
-#include <kparts/plugin.h>
+#include <tdeparts/plugin.h>
 
 class KisView;
 
 class ColorRange : public KParts::Plugin
 {
         Q_OBJECT
-  TQ_OBJECT
+  
     public:
         ColorRange(TQObject *parent, const char *name, const TQStringList &);
         virtual ~ColorRange();
