@@ -61,11 +61,11 @@ class TQPopup;
 class TQPopupMenu;
 
 class DCOPObject;
-class KAction;
-class KActionMenu;
+class TDEAction;
+class TDEActionMenu;
 class KPrinter;
-class KToggleAction;
-class KToolBar;
+class TDEToggleAction;
+class TDEToolBar;
 
 class KoPartSelectAction;
 class KoDocumentEntry;
@@ -118,7 +118,7 @@ class KRITA_EXPORT KisView
 {
 
     Q_OBJECT
-  TQ_OBJECT
+  
 
     typedef KoView super;
 
@@ -540,44 +540,44 @@ private:
     TQ_INT32 m_hScrollBarExtent;
 
     // Actions
-    KAction *m_imgFlatten;
-    KAction *m_imgMergeLayer;
-    KAction *m_imgRename;
-    KAction *m_imgResizeToLayer;
-    KAction *m_imgScan;
+    TDEAction *m_imgFlatten;
+    TDEAction *m_imgMergeLayer;
+    TDEAction *m_imgRename;
+    TDEAction *m_imgResizeToLayer;
+    TDEAction *m_imgScan;
 
     KoPartSelectAction * m_actionPartLayer;
-    KAction * m_actionAdjustmentLayer;
-    KAction *m_layerAdd;
-    KAction *m_layerBottom;
-    KAction *m_layerDup;
-    KToggleAction *m_layerHide;
-    KAction *m_layerLower;
-    KAction *m_layerProperties;
-    KAction *m_layerRaise;
-    KAction *m_layerRm;
-    KAction *m_layerSaveAs;
-    KAction *m_layerTop;
+    TDEAction * m_actionAdjustmentLayer;
+    TDEAction *m_layerAdd;
+    TDEAction *m_layerBottom;
+    TDEAction *m_layerDup;
+    TDEToggleAction *m_layerHide;
+    TDEAction *m_layerLower;
+    TDEAction *m_layerProperties;
+    TDEAction *m_layerRaise;
+    TDEAction *m_layerRm;
+    TDEAction *m_layerSaveAs;
+    TDEAction *m_layerTop;
 
-    KAction *m_createMask;
-    KAction *m_maskFromSelection;
-    KAction *m_maskToSelection;
-    KAction *m_applyMask;
-    KAction *m_removeMask;
-    KToggleAction *m_editMask;
-    KToggleAction *m_showMask;
+    TDEAction *m_createMask;
+    TDEAction *m_maskFromSelection;
+    TDEAction *m_maskToSelection;
+    TDEAction *m_applyMask;
+    TDEAction *m_removeMask;
+    TDEToggleAction *m_editMask;
+    TDEToggleAction *m_showMask;
 
-    KAction *m_zoomIn;
-    KAction *m_zoomOut;
-    KAction *m_actualPixels;
-    KAction *m_actualSize;
-    KAction *m_fitToCanvas;
+    TDEAction *m_zoomIn;
+    TDEAction *m_zoomOut;
+    TDEAction *m_actualPixels;
+    TDEAction *m_actualSize;
+    TDEAction *m_fitToCanvas;
 
-    KAction *m_fullScreen;
-    KAction *m_imgProperties;
+    TDEAction *m_fullScreen;
+    TDEAction *m_imgProperties;
 
-    KToggleAction *m_RulerAction;
-    KToggleAction *m_guideAction;
+    TDEToggleAction *m_RulerAction;
+    TDEToggleAction *m_guideAction;
 
     DCOPObject *m_dcop;
 
