@@ -26,22 +26,22 @@ DESCRIPTION
 
 #include <klibloader.h>
 
-class KInstance;
+class TDEInstance;
 
 class XFIGImportFactory :
     public KLibFactory
 {
     Q_OBJECT
-  TQ_OBJECT
+  
 public:
     XFIGImportFactory(TQObject* parent = 0, const char* name = 0);
     virtual ~XFIGImportFactory();
 
     virtual TQObject* createObject(TQObject* parent = 0, const char* name = 0, const char* classname = TQOBJECT_OBJECT_NAME_STRING, const TQStringList &args = TQStringList());
 
-    static KInstance* global();
+    static TDEInstance* global();
 
 private:
-    static KInstance* s_global;
+    static TDEInstance* s_global;
 };
 #endif
