@@ -37,7 +37,7 @@
 #include <tqdom.h>
 
 #include <kdebug.h>
-#include <klocale.h>
+#include <tdelocale.h>
 #include <kzip.h>
 
 #include <KoPageLayout.h>
