@@ -11,8 +11,8 @@
 #include <KoFactory.h>
 
 
-class KInstance;
-class KAboutData;
+class TDEInstance;
+class TDEAboutData;
 
 namespace KChart
 {
@@ -20,7 +20,7 @@ namespace KChart
 class KChartFactory : public KoFactory
 {
     Q_OBJECT
-  TQ_OBJECT
+  
 public:
     KChartFactory( TQObject* parent = 0, const char* name = 0 );
     virtual ~KChartFactory();
@@ -32,14 +32,14 @@ public:
 					     const char* classname = "KoDocument",
 					     const TQStringList &args = TQStringList() );
 
-    static KInstance* global();
+    static TDEInstance* global();
 
-    // _Creates_ a KAboutData but doesn't keep ownership
-    static KAboutData* aboutData();
+    // _Creates_ a TDEAboutData but doesn't keep ownership
+    static TDEAboutData* aboutData();
 
 private:
-    static KInstance* s_global;
-    static KAboutData *s_aboutData;
+    static TDEInstance* s_global;
+    static TDEAboutData *s_aboutData;
 };
 
 }  //namespace KChart
