@@ -75,7 +75,7 @@ class KDTimeHeaderToolTip;
 class KDTimeHeaderWidget : public TQWidget
 {
    Q_OBJECT
-  TQ_OBJECT
+  
 
 public:
    typedef KDGanttView::Scale Scale;
@@ -248,7 +248,7 @@ class KDListView ;
 class KDTimeTableWidget : public TQCanvas
 {
    Q_OBJECT
-  TQ_OBJECT
+  
 
 public:
    KDTimeTableWidget (TQWidget* parent,KDGanttView* my);
@@ -325,7 +325,7 @@ private:
 class KDLegendWidget : public KDGanttSemiSizingControl
 {
    Q_OBJECT
-  TQ_OBJECT
+  
 
 public:
   KDLegendWidget ( TQWidget* parent, KDGanttMinimizeSplitter* legendParent );
@@ -335,8 +335,8 @@ public:
   void clearLegend();
   void setFont( TQFont );
   void drawToPainter( TQPainter *p );
-  void setAsDockwindow( bool dockwin );
-  bool asDockwindow();
+  void setAsDoctwindow( bool dockwin );
+  bool asDoctwindow();
   TQDockWindow* dockwindow();
   TQSize legendSize();
   TQSize legendSizeHint();
@@ -352,7 +352,7 @@ class KDGanttView;
 class KDListView : public TQListView
 {
    Q_OBJECT
-  TQ_OBJECT
+  
 
 public:
    KDListView (TQWidget* parent,KDGanttView* gv );
@@ -454,7 +454,7 @@ class KDCanvasToolTip;
 class KDGanttCanvasView : public TQCanvasView
 {
     Q_OBJECT
-  TQ_OBJECT
+  
 
 public:
     KDGanttCanvasView(KDGanttView* sender, TQCanvas* canvas = 0, TQWidget* parent = 0, const char* name = 0 );
