@@ -26,8 +26,8 @@
 #include <tqregexp.h>
 
 #include <kdebug.h>
-#include <klocale.h>
-#include <kmessagebox.h>
+#include <tdelocale.h>
+#include <tdemessagebox.h>
 
 #include <kexidb/field.h>
 #include <kexidb/queryschema.h>
@@ -1372,7 +1372,7 @@ KexiQueryDesignerGuiEditor::parseExpressionString(const TQString& fullString, in
 	}
 	else if (str[0]>='0' && str[0]<='9' || str[0]=='-' || str[0]=='+') {
 		//number
-		TQString decimalSym = KGlobal::locale()->decimalSymbol();
+		TQString decimalSym = TDEGlobal::locale()->decimalSymbol();
 		bool ok;
 		int pos = str.find('.');
 		if (pos==-1) {//second chance: local decimal symbol
