@@ -29,7 +29,7 @@
 #include <tqlabel.h>
 #include <tqtooltip.h>
 
-#include <kmessagebox.h>
+#include <tdemessagebox.h>
 
 #include <kexi.h>
 #include <kexiutils/validator.h>
@@ -1210,7 +1210,7 @@ void KexiDataAwareObjectInterface::deleteCurrentRow()
 	case AskDelete:
 		if (KMessageBox::Cancel == KMessageBox::warningContinueCancel(dynamic_cast<TQWidget*>(this), 
 			i18n("Do you want to delete selected row?"), 0, 
-			KGuiItem(i18n("&Delete Row"),"editdelete"),
+			KGuiItem(i18n("&Delete Row"),"edit-delete"),
 			"dontAskBeforeDeleteRow"/*config entry*/,
 			KMessageBox::Notify|KMessageBox::Dangerous))
 			return;
