@@ -42,16 +42,16 @@
 #include <widget/utils/kexisharedactionclient.h>
 #include "kexidataawareobjectiface.h"
 
-class KPopupMenu;
+class TDEPopupMenu;
 class KPrinter;
-class KAction;
+class TDEAction;
 
 class KexiTableHeader;
 class KexiTableItem;
 class KexiTableView;
 class KexiTableEdit;
 class KexiTableViewPrivate;
-class KActionCollection;
+class TDEActionCollection;
 
 namespace KexiDB {
 	class RowEditBuffer;
@@ -70,7 +70,7 @@ class KEXIDATATABLE_EXPORT KexiTableView :
 	public KexiDataAwareObjectInterface
 {
 Q_OBJECT
-  TQ_OBJECT
+  
 KEXI_DATAAWAREOBJECTINTERFACE
 public:
 
@@ -94,7 +94,7 @@ public:
 		 current active palette */
 		TQColor emptyAreaColor;
 
-		/*! alternate background color, default is KGlobalSettings::alternateBackgroundColor() */
+		/*! alternate background color, default is TDEGlobalSettings::alternateBackgroundColor() */
 		TQColor alternateBackgroundColor;
 
 		/*! true if background altering should be enabled, true by default */
