@@ -21,7 +21,7 @@
 
 #include "KPrBackground.h"
 #include "KPrDocument.h"
-#include <kapplication.h>
+#include <tdeapplication.h>
 #include "KPrGradientCollection.h"
 #include "KPrTextObject.h"
 #include "KPrPage.h"
@@ -38,7 +38,7 @@
 #include <stdlib.h>
 using namespace std;
 #include <kdebug.h>
-#include <kglobalsettings.h>
+#include <tdeglobalsettings.h>
 #include <KoStore.h>
 #include <KoStoreDevice.h>
 #include <KoGenStyles.h>
@@ -525,7 +525,7 @@ void KPrBackGround::drawBackPix( TQPainter *_painter, const TQSize& ext, const T
         double w = _origSize.width();
         w *= ext.width();
 #if KDE_IS_VERSION(3,1,90)
-        TQRect desk = KGlobalSettings::desktopGeometry(TQT_TQWIDGET(kapp->activeWindow()));
+        TQRect desk = TDEGlobalSettings::desktopGeometry(TQT_TQWIDGET(kapp->activeWindow()));
 #else
         TQRect desk = TQApplication::desktop()->screenGeometry();
 #endif
