@@ -1885,7 +1885,7 @@ KoTextCursor * KPrOasisPasteTextCommand::execute( KoTextCursor *c )
 {
     KoTextParag *firstParag = doc->paragAt( m_parag );
     if ( !firstParag ) {
-        qWarning( "can't locate parag at %d, last parag: %d", m_parag, doc->lastParag()->paragId() );
+        tqWarning( "can't locate parag at %d, last parag: %d", m_parag, doc->lastParag()->paragId() );
         return 0;
     }
     //kdDebug() << "KWOasisPasteCommand::execute m_parag=" << m_parag << " m_idx=" << m_idx
@@ -1955,7 +1955,7 @@ KoTextCursor * KPrOasisPasteTextCommand::unexecute( KoTextCursor *c )
 {
     KoTextParag *firstParag = doc->paragAt( m_parag );
     if ( !firstParag ) {
-        qWarning( "can't locate parag at %d, last parag: %d", m_parag, doc->lastParag()->paragId() );
+        tqWarning( "can't locate parag at %d, last parag: %d", m_parag, doc->lastParag()->paragId() );
         return 0;
     }
     cursor.setParag( firstParag );
@@ -1964,7 +1964,7 @@ KoTextCursor * KPrOasisPasteTextCommand::unexecute( KoTextCursor *c )
 
     KoTextParag *lastParag = doc->paragAt( m_lastParag );
     if ( !lastParag ) {
-        qWarning( "can't locate parag at %d, last parag: %d", m_lastParag, doc->lastParag()->paragId() );
+        tqWarning( "can't locate parag at %d, last parag: %d", m_lastParag, doc->lastParag()->paragId() );
         return 0;
     }
     //Q_ASSERT( lastParag->document() );
