@@ -30,8 +30,8 @@
 #include <tqtooltip.h>
 
 #include <kwordwrap.h>
-#include <kmessagebox.h>
-#include <klocale.h>
+#include <tdemessagebox.h>
+#include <tdelocale.h>
 #include <kinputdialog.h>
 #include <knotifyclient.h>
 #include <kiconview.h>
@@ -89,11 +89,11 @@ private:
 };
 
 
-class OutlineSlideItem: public KListViewItem
+class OutlineSlideItem: public TDEListViewItem
 {
 public:
-    OutlineSlideItem( KListView * parent, KPrPage* page, bool _masterPage );
-    OutlineSlideItem( KListView * parent, OutlineSlideItem *after, KPrPage* page, bool _masterPage );
+    OutlineSlideItem( TDEListView * parent, KPrPage* page, bool _masterPage );
+    OutlineSlideItem( TDEListView * parent, OutlineSlideItem *after, KPrPage* page, bool _masterPage );
 
     KPrPage* page() const { return m_page; }
 
@@ -107,7 +107,7 @@ private:
     bool m_masterPage;
 };
 
-class OutlineObjectItem: public KListViewItem
+class OutlineObjectItem: public TDEListViewItem
 {
 public:
     OutlineObjectItem( OutlineSlideItem * parent, KPrObject* object,
@@ -234,7 +234,7 @@ void KPrSideBarBase::setViewMasterPage( bool _b )
 }
 
 KPrThumbBar::KPrThumbBar(TQWidget *parent, KPrDocument *d, KPrView *v)
-    :KIconView(parent), KPrSideBarBase( d,v)
+    :TDEIconView(parent), KPrSideBarBase( d,v)
 {
     uptodate = false;
     m_offsetX = 0;
@@ -577,16 +577,16 @@ void KPrThumbBar::slotRefreshItems()
     refreshItems();
 }
 
-OutlineSlideItem::OutlineSlideItem( KListView* parent, KPrPage* _page, bool _masterPage )
-    : KListViewItem( parent ), m_page( _page ), m_masterPage( _masterPage )
+OutlineSlideItem::OutlineSlideItem( TDEListView* parent, KPrPage* _page, bool _masterPage )
+    : TDEListViewItem( parent ), m_page( _page ), m_masterPage( _masterPage )
 {
     setDragEnabled(true);
     setPage( _page );
     setPixmap( 0, KPBarIcon( "slide" ) );
 }
 
-OutlineSlideItem::OutlineSlideItem( KListView* parent, OutlineSlideItem * after, KPrPage* _page, bool _masterPage )
-    : KListViewItem( parent, after ), m_page( _page ), m_masterPage( _masterPage )
+OutlineSlideItem::OutlineSlideItem( TDEListView* parent, OutlineSlideItem * after, KPrPage* _page, bool _masterPage )
+    : TDEListViewItem( parent, after ), m_page( _page ), m_masterPage( _masterPage )
 {
     setDragEnabled(true);
     setPage( _page );
@@ -678,7 +678,7 @@ void OutlineSlideItem::updateTitle()
 
 OutlineObjectItem::OutlineObjectItem( OutlineSlideItem* parent, KPrObject* _object,
                                       const TQString& name )
-    : KListViewItem( parent ), m_object( _object )
+    : TDEListViewItem( parent ), m_object( _object )
 {
     setObject( m_object );
     setDragEnabled( false );
@@ -756,7 +756,7 @@ void OutlineObjectItem::setObject( KPrObject* object )
 }
 
 KPrOutline::KPrOutline( TQWidget *parent, KPrDocument *d, KPrView *v )
-    : KListView( parent ), KPrSideBarBase( d, v)
+    : TDEListView( parent ), KPrSideBarBase( d, v)
 {
     rebuildItems();
     setSorting( -1 );
@@ -767,8 +767,8 @@ KPrOutline::KPrOutline( TQWidget *parent, KPrDocument *d, KPrView *v )
     connect( this, TQT_SIGNAL( currentChanged( TQListViewItem * ) ), this, TQT_SLOT( itemClicked( TQListViewItem * ) ) );
     connect( this, TQT_SIGNAL( rightButtonPressed( TQListViewItem *, const TQPoint &, int ) ),
              this, TQT_SLOT( rightButtonPressed( TQListViewItem *, const TQPoint &, int ) ) );
-    connect( this, TQT_SIGNAL( contextMenu( KListView*, TQListViewItem*, const TQPoint& ) ),
-             this, TQT_SLOT( slotContextMenu( KListView*, TQListViewItem*, const TQPoint&) ) );
+    connect( this, TQT_SIGNAL( contextMenu( TDEListView*, TQListViewItem*, const TQPoint& ) ),
+             this, TQT_SLOT( slotContextMenu( TDEListView*, TQListViewItem*, const TQPoint&) ) );
 
     connect( this, TQT_SIGNAL( doubleClicked ( TQListViewItem * )),
              this, TQT_SLOT(renamePageTitle()));
@@ -883,7 +883,7 @@ void KPrOutline::moveItem( int oldPos, int newPos )
             item->updateTitle();
     }
 
-    KListView::moveItem( itemToMove, 0, itemAfter );
+    TDEListView::moveItem( itemToMove, 0, itemAfter );
 }
 
 void KPrOutline::removeItem( int pos )
@@ -954,7 +954,7 @@ void KPrOutline::slotDropped( TQDropEvent * /* e */, TQListViewItem *parent, TQL
     if ( parent )
         return;
 
-    // This code is taken from KListView
+    // This code is taken from TDEListView
     for (TQListViewItem *i = firstChild(), *iNext = 0; i != 0; i = iNext)
     {
         iNext = i->itemBelow();
@@ -1000,7 +1000,7 @@ void KPrOutline::setCurrentPage( int pg )
 void KPrOutline::contentsDropEvent( TQDropEvent *e )
 {
     disconnect( this, TQT_SIGNAL( currentChanged( TQListViewItem * ) ), this, TQT_SLOT( itemClicked( TQListViewItem * ) ) );
-    KListView::contentsDropEvent( e );
+    TDEListView::contentsDropEvent( e );
     connect( this, TQT_SIGNAL( currentChanged( TQListViewItem * ) ), this, TQT_SLOT( itemClicked( TQListViewItem * ) ) );
 }
 
@@ -1058,7 +1058,7 @@ void KPrOutline::rightButtonPressed( TQListViewItem *, const TQPoint &pnt, int )
     }
 }
 
-void KPrOutline::slotContextMenu( KListView*, TQListViewItem* item, const TQPoint& p )
+void KPrOutline::slotContextMenu( TDEListView*, TQListViewItem* item, const TQPoint& p )
 {
     rightButtonPressed( item, p, 0 );
 }
@@ -1105,7 +1105,7 @@ TQDragObject* KPrOutline::dragObject()
       return 0;
     }
 
-    return KListView::dragObject();
+    return TDEListView::dragObject();
 }
 
 #include "KPrSideBar.moc"
