@@ -42,11 +42,11 @@
 #include "KPrTextObjectIface.h"
 #include <KoOasisContext.h>
 #include <KoStyleStack.h>
-#include <ktempfile.h>
-#include <klocale.h>
+#include <tdetempfile.h>
+#include <tdelocale.h>
 #include <kdebug.h>
-#include <kdeversion.h>
-#include <kmultipledrag.h>
+#include <tdeversion.h>
+#include <tdemultipledrag.h>
 
 #include <tqfont.h>
 #include <tqfile.h>
@@ -61,7 +61,7 @@
 #include <tqclipboard.h>
 
 #include <KoParagCounter.h>
-#include <kaction.h>
+#include <tdeaction.h>
 #include <KoVariable.h>
 #include <KoCustomVariablesDia.h>
 #include <KoRuler.h>
@@ -77,33 +77,33 @@ using namespace std;
 
 #undef S_NONE // Solaris defines it in sys/signal.h
 
-const TQString &KPrTextObject::tagTEXTOBJ=KGlobal::staticQString("TEXTOBJ");
-const TQString &KPrTextObject::attrLineSpacing=KGlobal::staticQString("lineSpacing");
-const TQString &KPrTextObject::attrParagSpacing=KGlobal::staticQString("paragSpacing");
-const TQString &KPrTextObject::attrMargin=KGlobal::staticQString("margin");
-const TQString &KPrTextObject::attrBulletType1=KGlobal::staticQString("bulletType1");
-const TQString &KPrTextObject::attrBulletType2=KGlobal::staticQString("bulletType2");
-const TQString &KPrTextObject::attrBulletType3=KGlobal::staticQString("bulletType3");
-const TQString &KPrTextObject::attrBulletType4=KGlobal::staticQString("bulletType4");
-const TQString &KPrTextObject::attrBulletColor1=KGlobal::staticQString("bulletColor1");
-const TQString &KPrTextObject::attrBulletColor2=KGlobal::staticQString("bulletColor2");
-const TQString &KPrTextObject::attrBulletColor3=KGlobal::staticQString("bulletColor3");
-const TQString &KPrTextObject::attrBulletColor4=KGlobal::staticQString("bulletColor4");
-const TQString &KPrTextObject::tagP=KGlobal::staticQString("P");
-const TQString &KPrTextObject::attrAlign=KGlobal::staticQString("align");
-const TQString &KPrTextObject::attrType=KGlobal::staticQString("type");
-const TQString &KPrTextObject::attrDepth=KGlobal::staticQString("depth");
-const TQString &KPrTextObject::tagTEXT=KGlobal::staticQString("TEXT");
-const TQString &KPrTextObject::attrFamily=KGlobal::staticQString("family");
-const TQString &KPrTextObject::attrPointSize=KGlobal::staticQString("pointSize");
-const TQString &KPrTextObject::attrBold=KGlobal::staticQString("bold");
-const TQString &KPrTextObject::attrItalic=KGlobal::staticQString("italic");
-const TQString &KPrTextObject::attrUnderline=KGlobal::staticQString("underline");
-const TQString &KPrTextObject::attrStrikeOut=KGlobal::staticQString("strikeOut");
-const TQString &KPrTextObject::attrColor=KGlobal::staticQString("color");
-const TQString &KPrTextObject::attrWhitespace=KGlobal::staticQString("whitespace");
-const TQString &KPrTextObject::attrTextBackColor=KGlobal::staticQString("textbackcolor");
-const TQString &KPrTextObject::attrVertAlign=KGlobal::staticQString("VERTALIGN");
+const TQString &KPrTextObject::tagTEXTOBJ=TDEGlobal::staticQString("TEXTOBJ");
+const TQString &KPrTextObject::attrLineSpacing=TDEGlobal::staticQString("lineSpacing");
+const TQString &KPrTextObject::attrParagSpacing=TDEGlobal::staticQString("paragSpacing");
+const TQString &KPrTextObject::attrMargin=TDEGlobal::staticQString("margin");
+const TQString &KPrTextObject::attrBulletType1=TDEGlobal::staticQString("bulletType1");
+const TQString &KPrTextObject::attrBulletType2=TDEGlobal::staticQString("bulletType2");
+const TQString &KPrTextObject::attrBulletType3=TDEGlobal::staticQString("bulletType3");
+const TQString &KPrTextObject::attrBulletType4=TDEGlobal::staticQString("bulletType4");
+const TQString &KPrTextObject::attrBulletColor1=TDEGlobal::staticQString("bulletColor1");
+const TQString &KPrTextObject::attrBulletColor2=TDEGlobal::staticQString("bulletColor2");
+const TQString &KPrTextObject::attrBulletColor3=TDEGlobal::staticQString("bulletColor3");
+const TQString &KPrTextObject::attrBulletColor4=TDEGlobal::staticQString("bulletColor4");
+const TQString &KPrTextObject::tagP=TDEGlobal::staticQString("P");
+const TQString &KPrTextObject::attrAlign=TDEGlobal::staticQString("align");
+const TQString &KPrTextObject::attrType=TDEGlobal::staticQString("type");
+const TQString &KPrTextObject::attrDepth=TDEGlobal::staticQString("depth");
+const TQString &KPrTextObject::tagTEXT=TDEGlobal::staticQString("TEXT");
+const TQString &KPrTextObject::attrFamily=TDEGlobal::staticQString("family");
+const TQString &KPrTextObject::attrPointSize=TDEGlobal::staticQString("pointSize");
+const TQString &KPrTextObject::attrBold=TDEGlobal::staticQString("bold");
+const TQString &KPrTextObject::attrItalic=TDEGlobal::staticQString("italic");
+const TQString &KPrTextObject::attrUnderline=TDEGlobal::staticQString("underline");
+const TQString &KPrTextObject::attrStrikeOut=TDEGlobal::staticQString("strikeOut");
+const TQString &KPrTextObject::attrColor=TDEGlobal::staticQString("color");
+const TQString &KPrTextObject::attrWhitespace=TDEGlobal::staticQString("whitespace");
+const TQString &KPrTextObject::attrTextBackColor=TDEGlobal::staticQString("textbackcolor");
+const TQString &KPrTextObject::attrVertAlign=TDEGlobal::staticQString("VERTALIGN");
 
 
 KPrTextObject::KPrTextObject(  KPrDocument *doc )
@@ -2211,14 +2211,14 @@ void KPrTextView::mouseReleaseEvent( TQMouseEvent *, const TQPoint & )
     handleMouseReleaseEvent();
 }
 
-void KPrTextView::showPopup( KPrView *view, const TQPoint &point, TQPtrList<KAction>& actionList )
+void KPrTextView::showPopup( KPrView *view, const TQPoint &point, TQPtrList<TDEAction>& actionList )
 {
     TQString word = wordUnderCursor( *cursor() );
     view->unplugActionList( "datatools" );
     view->unplugActionList( "datatools_link" );
     view->unplugActionList( "spell_result_action" );
     view->unplugActionList( "variable_action" );
-    TQPtrList<KAction> &variableList = view->variableActionList();
+    TQPtrList<TDEAction> &variableList = view->variableActionList();
     variableList.clear();
     actionList.clear();
 
@@ -2259,7 +2259,7 @@ void KPrTextView::showPopup( KPrView *view, const TQPoint &point, TQPtrList<KAct
             {
                 if ( singleWord )
                 {
-                    TQPtrList<KAction> actionCheckSpellList =view->listOfResultOfCheckWord( word );
+                    TQPtrList<TDEAction> actionCheckSpellList =view->listOfResultOfCheckWord( word );
                     if ( actionCheckSpellList.count()>0)
                     {
                         view->plugActionList( "spell_result_action", actionCheckSpellList );
@@ -2407,11 +2407,11 @@ TQDragObject * KPrTextView::newDrag( TQWidget * parent )
     oasisStore.closeContentWriter();
 
     if ( !store->open( "styles.xml" ) )
-        return false;
+        return 0;
     //manifestWriter->addManifestEntry( "styles.xml", "text/xml" );
     doc->saveOasisDocumentStyles( store, mainStyles, 0, savingContext, KPrDocument::SaveSelected /* simply means not SaveAll */ );
     if ( !store->close() ) // done with styles.xml
-        return false;
+        return 0;
 
     delete store;
 
