@@ -24,7 +24,7 @@
 #include <config.h>
 #endif
 
-#include <kmainwindow.h>
+#include <tdemainwindow.h>
 
 #include <koproperty/set.h>
 
@@ -33,10 +33,10 @@
  * @author Cedric Pasteur <cedric.pasteur@free.fr>
  * @version 0.1
  */
-class Test : public KMainWindow
+class Test : public TDEMainWindow
 {
 	Q_OBJECT
-  TQ_OBJECT
+  
 	public:
 	    Test();
 		virtual ~Test();
